import { type Diagnostic, DiagnosticCategory } from 'typescript';
import type { Issue } from '@code-pushup/models';
import type { CodeRangeName } from './types.js';
/**
 * Transform the TypeScript error code to the audit slug.
 * @param code - The TypeScript error code.
 * @returns The audit slug.
 * @throws Error if the code is not supported.
 */
export declare function tsCodeToAuditSlug(code: number): CodeRangeName;
/**
 * Get the severity of the issue based on the TypeScript diagnostic category.
 * - ts.DiagnosticCategory.Warning (1)
 * - ts.DiagnosticCategory.Error (2)
 * - ts.DiagnosticCategory.Suggestion (3)
 * - ts.DiagnosticCategory.Message (4)
 * @param category - The TypeScript diagnostic category.
 * @returns The severity of the issue.
 */
export declare function getSeverity(category: DiagnosticCategory): Issue['severity'];
/**
 * Format issue message from the TypeScript diagnostic.
 * @param diag - The TypeScript diagnostic.
 * @returns The issue message.
 */
export declare function getMessage(diag: Diagnostic): string;
/**
 * Get the issue from the TypeScript diagnostic.
 * @param diag - The TypeScript diagnostic.
 * @returns The issue.
 * @throws Error if the diagnostic is global (e.g., invalid compiler option).
 */
export declare function getIssueFromDiagnostic(diag: Diagnostic): {
    message: string;
    severity: "info" | "warning" | "error";
    source?: {
        file: string;
        position?: {
            startLine: number;
            startColumn?: number | undefined;
            endLine?: number | undefined;
            endColumn?: number | undefined;
        } | undefined;
    } | undefined;
};
export declare function loadTargetConfig(tsConfigPath: string): Promise<import("typescript").ParsedCommandLine>;
