import type { CompilerOptions } from 'typescript';
import type { Audit, CategoryConfig, CategoryRef } from '@code-pushup/models';
import type { TypescriptPluginConfig, TypescriptPluginOptions } from './schema.js';
/**
 * It filters the audits by the slugs
 *
 * @param slugs
 */
export declare function filterAuditsBySlug(slugs?: string[]): ({ slug }: {
    slug: string;
}) => boolean;
/**
 * From a list of audits, it will filter out the ones that might have been disabled from the compiler options
 * plus from the parameter onlyAudits
 * @param compilerOptions Compiler options
 * @param onlyAudits OnlyAudits
 * @returns Filtered Audits
 */
export declare function filterAuditsByCompilerOptions(compilerOptions: CompilerOptions, onlyAudits?: string[]): ({ slug }: {
    slug: string;
}) => boolean;
export declare function getGroups(options?: TypescriptPluginOptions): {
    refs: {
        slug: string;
        weight: number;
    }[];
    slug: string;
    title: string;
    description?: string | undefined;
    docsUrl?: string | undefined;
    isSkipped?: boolean | undefined;
}[];
export declare function getAudits(options?: Pick<TypescriptPluginConfig, 'onlyAudits'>): ({
    slug: string;
    title: string;
    description?: string | undefined;
    docsUrl?: string | undefined;
    isSkipped?: boolean | undefined;
} & {
    slug: import("./types.js").AuditSlug;
})[];
/**
 * Retrieve the category references from the groups (already processed from the audits).
 * Used in the code-pushup preset
 * @param opt TSPluginOptions
 * @returns The array of category references
 */
export declare function getCategoryRefsFromGroups(opt?: TypescriptPluginOptions): CategoryRef[];
/**
 * Retrieve the category references from the audits.
 * @param opt TSPluginOptions
 * @returns The array of category references
 */
export declare function getCategoryRefsFromAudits(opt?: TypescriptPluginOptions): CategoryRef[];
export declare const CATEGORY_MAP: Record<string, CategoryConfig>;
export declare function getCategories(): {
    slug: string;
    refs: {
        slug: string;
        weight: number;
        type: "audit" | "group";
        plugin: string;
    }[];
    title: string;
    description?: string | undefined;
    docsUrl?: string | undefined;
    isSkipped?: boolean | undefined;
    isBinary?: boolean | undefined;
}[];
export declare function logSkippedAudits(audits: Audit[]): void;
